/* $Id: GVApplicationDelegate.m,v 1.2 2009/02/26 12:44:55 glenlow Exp $ $Revision: 1.2 $ */
/* vim:set shiftwidth=4 ts=8: */

/**********************************************************
*      This software is part of the graphviz package      *
*                http://www.graphviz.org/                 *
*                                                         *
*            Copyright (c) 1994-2008 AT&T Corp.           *
*                and is licensed under the                *
*            Common Public License, Version 1.0           *
*                      by AT&T Corp.                      *
*                                                         *
*        Information and Software Systems Research        *
*              AT&T Research, Florham Park NJ             *
**********************************************************/

#import "GVApplicationDelegate.h"
#import "GVAttributeInspectorController.h"

@implementation GVApplicationDelegate

- (IBAction)showAttributeInspector:(id)sender
{
	if (!_attributeInspectorController)
		_attributeInspectorController = [[GVAttributeInspectorController alloc] init];
	[_attributeInspectorController showWindow:sender];
}

- (BOOL)applicationOpenUntitledFile:(NSApplication*)theApplication
{
	if (!_applicationStarted)
		[[NSDocumentController sharedDocumentController] openDocument:self];
	return YES;
}

- (void)applicationDidFinishLaunching:(NSNotification*)aNotification
{
	_applicationStarted = YES;
}

@end
